Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(454)

Unified Diff: content/public/browser/web_contents_delegate.h

Issue 1181293003: Expand SecurityStyleChanged interfaces to include explanations (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments, style tweaks Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/web_contents_delegate.h
diff --git a/content/public/browser/web_contents_delegate.h b/content/public/browser/web_contents_delegate.h
index f191672c9d9c21b3a98b07dc9bbd5e967c8b3dec..628c5ffa62ed0ac499d0569ffd037db166586baa 100644
--- a/content/public/browser/web_contents_delegate.h
+++ b/content/public/browser/web_contents_delegate.h
@@ -486,9 +486,13 @@ class CONTENT_EXPORT WebContentsDelegate {
// default behavior is suppressed.
virtual bool SaveFrame(const GURL& url, const Referrer& referrer);
- // Can be overridden by a delegate to return the security style of the given
- // |web_contents|. Returns SECURITY_STYLE_UNKNOWN if not overriden.
- virtual SecurityStyle GetSecurityStyle(WebContents* web_contents);
+ // Can be overridden by a delegate to return the security style of the
+ // given |web_contents|, populating |security_style_explanation| to
+ // explain why the SecurityStyle was downgraded. Returns
+ // SECURITY_STYLE_UNKNOWN if not overriden.
+ virtual SecurityStyle GetSecurityStyle(
+ WebContents* web_contents,
+ SecurityStyleExplanation* security_style_explanation);
protected:
virtual ~WebContentsDelegate();

Powered by Google App Engine
This is Rietveld 408576698